<?php

namespace Netzmacher\QuickShop\TCA\Columns\Type;

use Netzmacher\QuickShop\Utility\Userfunc\TYPO3v;

/* * *************************************************************
 *  Copyright notice
 *
 *  (c) 2018-2019 - Dirk Wildt <http://wildt.at.die-netzmacher.de/>
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 * ************************************************************* */

/**
 * @version 9.2.0
 * @since 8.10.0
 */
class Items
{

	public static $pathDefault = 'EXT:quick_shop/ext_icon';
	public static $pathInquiryform = 'EXT:quick_shop/Resources/Public/Images/Icons/ExtIcon/inquiryform';
	public static $pathNotype = 'EXT:quick_shop/Resources/Public/Images/Icons/ExtIcon/notype';
	public static $pathPage = 'EXT:quick_shop/Resources/Public/Images/Icons/ExtIcon/page';
	public static $pathProduct = 'EXT:quick_shop/Resources/Public/Images/Icons/ExtIcon/product';
	public static $pathRecord = 'EXT:quick_shop/Resources/Public/Images/Icons/ExtIcon/record';
	public static $pathUrl = 'EXT:quick_shop/Resources/Public/Images/Icons/ExtIcon/url';

	/**
	 * Get path of the icon default
	 *
	 * @return      string path
	 * @version     7.0.2
	 * @since       7.0.2
	 */
	static public function IconDefault()
	{
		return SELF::_getPath( 'default' );
	}

	/**
	 * Get path of the icon notype
	 *
	 * @return      string path
	 * @version     7.0.2
	 * @since       7.0.2
	 */
	static public function IconNotype()
	{
		return SELF::_getPath( 'notype' );
	}

	/**
	 * Get path of the icon page
	 *
	 * @return      string path
	 * @version     7.0.2
	 * @since       7.0.2
	 */
	static public function IconPage()
	{
		return SELF::_getPath( 'page' );
	}

	/**
	 * Get path of the icon inquiryform
	 *
	 * @return      string path
	 * @version     9.2.0
	 * @since       9.2.0
	 */
	static public function IconInquiryform()
	{
		return SELF::_getPath( 'inquiryform' );
	}

	/**
	 * Get path of the icon product
	 *
	 * @return      string path
	 * @version     9.2.0
	 * @since       9.2.0
	 */
	static public function IconProduct()
	{
		return SELF::_getPath( 'product' );
	}

	/**
	 * Get path of the icon record
	 *
	 * @return      string path
	 * @version     7.0.2
	 * @since       7.0.2
	 */
	static public function IconRecord()
	{
		return SELF::_getPath( 'record' );
	}

	/**
	 * Get path of the icon url
	 *
	 * @return      string path
	 * @version     7.0.2
	 * @since       7.0.2
	 */
	static public function IconUrl()
	{
		return SELF::_getPath( 'url' );
	}

	/**
	 * Get icon array with classes and paths
	 *
	 * @return      void
	 * @version     9.2.0
	 * @since       7.0.2
	 */
	static private function _getPath( $icon )
	{
		switch( TRUE )
		{
			case( TYPO3v::get() < 7006000 ):
				$ext = 'gif';
				break;
			case( TYPO3v::get() >= 7006000 ):
			default:
				$ext = 'svg';
				break;
		}

		switch( $icon )
		{
			case('inquiryform'):
				return SELF::$pathInquiryform . '.' . $ext;
			case('notype'):
				return SELF::$pathNotype . '.' . $ext;
			case('page'):
				return SELF::$pathPage . '.' . $ext;
			case('product'):
				return SELF::$pathProduct . '.' . $ext;
			case('record'):
				return SELF::$pathRecord . '.' . $ext;
			case('url'):
				return SELF::$pathUrl . '.' . $ext;
			case('default'):
			default:
				return SELF::$pathDefault . '.' . $ext;
		}
	}

}
