<?php

namespace Netzmacher\QuickShop\TCA;

use TYPO3\CMS\Core\Utility\VersionNumberUtility;

if( !defined( 'TYPO3_MODE' ) )
{
	die( 'Access denied.' );
}

/* * *************************************************************
 *  Copyright notice
 *
 *  (c) 2017-2019 -  Dirk Wildt <http://wildt.at.die-netzmacher.de>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 * ************************************************************* */

/**
 * @author      Dirk Wildt <http://wildt.at.die-netzmacher.de>
 * @package     TYPO3
 * @subpackage  quick_shop
 * @version     8.14.0
 * @since       7.0.2
 */
class Types
{

	/**
	 * @access public
	 * @param				string	$case: small || medieum || big
	 * @param				boolean $fal
	 * @return      string
	 * @version     8.10.0
	 * @since       7.0.2
	 */
	static public function Image( $case = 'big', $fal = 1 )
	{
		switch( $fal )
		{
			case(false):
				return SELF::_ImageCSV( $case );
			case(true):
			default:
				return SELF::_ImageFAL( $case );
		}
	}

	/**
	 * @access			private
	 * @return      string
	 * @version     8.14.0
	 * @since       8.14.0
	 */
	static public function Media( )
	{
		$tcaTypesMediaFAL = ''
						. '--div--;LLL:EXT:quick_shop/Resources/Private/Language/6x/cms/locallang_ttc.xlf:tabs.media,'
						. '  --palette--;LLL:EXT:quick_shop/Resources/Private/Language/6x/cms/locallang_ttc.xlf:media;documents_upload,'
						. '  --palette--;LLL:EXT:quick_shop/Resources/Private/Language/tx_quickshop.xml:palette.appearance;documents_appearance,'
		;

		return $tcaTypesMediaFAL;
	}

	/**
	 * @access private
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _ImageCSV( $case = 'big' )
	{
		$_pathLL = SELF::_pathLL();

		switch( $case )
		{
			case('small'):
				return SELF::_ImageCSVsmall( $_pathLL );
			case('medium'):
				return SELF::_ImageCSVmedium( $_pathLL );
			case('big'):
			default:
				return SELF::_ImageCSVbig( $_pathLL );
		}
	}

	/**
	 * @access private
	 * @param				string $_pathLL locallang string
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _ImageCSVbig( $_pathLL )
	{
		return ''
						. '--div--;LLL:EXT:' . $_pathLL . ':tabs.images,'
						. '  --palette--;LLL:EXT:' . $_pathLL . ':palette.imagefiles;imagefiles,'
						. '  --palette--;LLL:EXT:quick_shop/Resources/Private/Language/tx_quickshop.xml:palette.image_1stforlistonly;image_1stforlistonly,'
						. '  --palette--;LLL:EXT:quick_shop/Resources/Private/Language/tx_quickshop.xml:palette.image_accessibility;image_accessibility,'
						. '  --palette--;LLL:EXT:' . $_pathLL . ':palette.imageblock;imageblock,'
						. '  --palette--;LLL:EXT:' . $_pathLL . ':palette.imagelinks;imagelinks,'
						. '  --palette--;LLL:EXT:' . $_pathLL . ':palette.image_settings;image_settings,'
		;
	}

	/**
	 * @access private
	 * @param				string $_pathLL locallang string
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _ImageCSVmedium( $_pathLL )
	{
		return ''
						. '--div--;LLL:EXT:' . $_pathLL . ':tabs.images,'
						. '  --palette--;LLL:EXT:' . $_pathLL . ':palette.image_settings;image_settings,'
						. '--div--;LLL:EXT:quick_shop/Resources/Private/Language/tx_quickshop.xml:div_seo, '
						. '  imageseo,'
		;
	}

	/**
	 * @access private
	 * @param				string $_pathLL locallang string
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _ImageCSVsmall( $_pathLL )
	{
		return ''
						. '--div--;LLL:EXT:' . $_pathLL . ':tabs.images,'
		;
	}

	/**
	 * @access private
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _ImageFAL( $case = 'big' )
	{
		$TYPO3_version = VersionNumberUtility::convertVersionNumberToInteger( TYPO3_version );

		switch( TRUE )
		{
			case ( $TYPO3_version < 8007000 ):
				return SELF::_ImageFALCss( $case );
			case ( $TYPO3_version >= 8007000 ):
			default:
				return SELF::_ImageFALFluid( $case );
		}
	}

	/**
	 * @access private
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _ImageFALCss( $case = 'big' )
	{
		switch( $case )
		{
			case('small'):
				return SELF::_ImageFALCssSmall();
			case('medium'):
				return SELF::_ImageFALCssMedium();
			case('big'):
			default:
				return SELF::_ImageFALCssBig();
		}
	}

	/**
	 * @access private
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _ImageFALCssBig()
	{
		$_pathLL = SELF::_pathLL();

		return ''
						. '--div--;LLL:EXT:' . $_pathLL . ':tabs.images,image,'
						. '  --palette--;LLL:EXT:quick_shop/Resources/Private/Language/locallang_db.xml:palette.image_1stforlistonly;image_1stforlistonly,'
						. '  --palette--;LLL:EXT:' . $_pathLL . ':palette.imagelinks;imagelinks,'
						. '--div--;LLL:EXT:' . $_pathLL . ':tabs.appearance,'
						. '  --palette--;LLL:EXT:' . $_pathLL . ':palette.frames;frames,'
						. '  --palette--;LLL:EXT:' . $_pathLL . ':palette.image_settings;image_settings,'
						. '  --palette--;LLL:EXT:' . $_pathLL . ':palette.imageblock;imageblock,'
		;
	}

	/**
	 * @access private
	 * @param				string $_pathLL locallang string
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _ImageFALCssMedium()
	{
		$_pathLL = SELF::_pathLL();

		return ''
						. '--div--;LLL:EXT:' . $_pathLL . ':tabs.images,image,'
						. '  --palette--;LLL:EXT:' . $_pathLL . ':palette.image_settings;image_settings,'
		;
	}

	/**
	 * @access private
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _ImageFALCssSmall()
	{
		$_pathLL = SELF::_pathLL();

		return ''
						. '--div--;LLL:EXT:' . $_pathLL . ':tabs.images,image,'
		;
	}

	/**
	 * @access private
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _ImageFALFluid( $case = 'big' )
	{
		switch( $case )
		{
			case('small'):
				return SELF::_ImageFALFluidSmall();
			case('medium'):
				return SELF::_ImageFALFluidMedium();
			case('big'):
			default:
				return SELF::_ImageFALFluidBig();
		}
	}

	/**
	 * @access private
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _ImageFALFluidBig()
	{
		return ''
						. '--div--;LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:tabs.images,image,'
						. '  --palette--;LLL:EXT:quick_shop/Resources/Private/Language/tx_quickshop.xmlpalette.image_1stforlistonly;image_1stforlistonly,'
						. '  --palette--;LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:palette.imagelinks;imagelinks,'
						. '--div--;LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:tabs.appearance,'
						. '  --palette--;LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:palette.frames;frames,'
						. '  --palette--;LLL:EXT:frontend/Resources/Private/Language/Database.xlf:tt_content.palette.mediaAdjustments;mediaAdjustments,'
						. '  --palette--;LLL:EXT:frontend/Resources/Private/Language/Database.xlf:tt_content.palette.gallerySettings;gallerySettings,'
						. '  --palette--;LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:palette.appearanceLinks;appearanceLinks,'
		;
	}

	/**
	 * @access private
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _ImageFALFluidMedium()
	{
		$_pathLL = SELF::_pathLL();

		return ''
						. '--div--;LLL:EXT:' . $_pathLL . ':tabs.images,image,'
						. '  --palette--;LLL:EXT:' . $_pathLL . ':palette.image_settings;image_settings,'
		;
	}

	/**
	 * @access private
	 * @param				string $_pathLL locallang string
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _ImageFALFluidSmall()
	{
		$_pathLL = SELF::_pathLL();

		return ''
						. '--div--;LLL:EXT:' . $_pathLL . ':tabs.images,image,'
		;
	}

	/**
	 * @access private
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _pathLL()
	{
		$TYPO3_version = VersionNumberUtility::convertVersionNumberToInteger( TYPO3_version );

		switch( TRUE )
		{
			case ( $TYPO3_version < 7006000 ):
				return 'quick_shop/Resources/Private/Language/6x/cms/locallang_ttc.xlf';
			case ( $TYPO3_version >= 7006000 ):
			default:
				return 'frontend/Resources/Private/Language/locallang_ttc.xlf';
		}
	}

}
